## KDE/acinclude.m4 (Macros for autoconf) (modified)
##
## (C) 1997 Janos Farkas
## (C) 1997 Stephan Kulow

## ------------------------------------------------------------------------
## Find a file (or one of more files in a list of dirs)
## ------------------------------------------------------------------------
##
AC_DEFUN(AC_FIND_FILE,
[
$3=NO
for i in $2;
do
  for j in $1;
  do
    if test -r "$i/$j"; then
      $3=$i
      break 2
    fi
  done
done
])

## ------------------------------------------------------------------------
## Internal macros to find if we don't need extra flags to find these
## This is not yet used
## ------------------------------------------------------------------------
##
AC_DEFUN(AC_PATH_QT_DIRECT,
[if test "$ac_qt_includes" = NO; then
AC_TRY_CPP([#include <qtstream.h>],
[
ac_qt_includes=
],[
])
fi
])

## ------------------------------------------------------------------------
## Find the meta object compiler in the PATH, in $QTDIR/bin, and some
## more usual places
## ------------------------------------------------------------------------
##
AC_DEFUN(AC_PATH_QT_MOC,
[
AC_PATH_PROG(MOC, moc, /usr/bin/moc,
 $PATH:/usr/bin:/usr/X11R6/bin:$QTDIR/bin:/usr/lib/qt/bin:/usr/local/qt/bin)
])

## ------------------------------------------------------------------------
## Try to find the QT headers and libraries.
## $(QT_LDLFLAGS) will be -Lqtliblocation (if needed)
## and $(QT_INCLUDES) will be -Iqthdrlocation (if needed)
## ------------------------------------------------------------------------
##
AC_DEFUN(AC_PATH_QT,
[
AC_REQUIRE_CPP()

AC_MSG_CHECKING([for qt>=1.30])
ac_qt_includes=NO ac_qt_libraries=NO
qt_libraries=""
qt_includes=""
AC_ARG_WITH(qt-dir,
    [  --with-qt-dir           where the root of qt is installed ],
    [  ac_qt_includes="$withval"/include
       ac_qt_libraries="$withval"/lib
    ])

AC_ARG_WITH(qt-includes,
    [  --with-qt-includes      where the qt includes are. ],
    [  
       ac_qt_includes="$withval"
    ])
    
AC_ARG_WITH(qt-libraries,
    [  --with-qt-libraries     where the qt library is installed.],
    [  ac_qt_libraries="$withval"
    ])

AC_ARG_ENABLE(qt-embedded,[  --enable-qt-embedded    Enable Qt Embedded support (adds -fno-rtti and -DQWS)],
            ac_qt_want_qte=$enableval,ac_qt_want_qte=no)

AC_ARG_ENABLE(qpe,[  --enable-qpe            Enable QPE support (implies --enable-qt-embedded)],
            ac_qt_want_qpe=$enableval ac_qt_want_qte=yes,ac_qt_want_qpe=no)

AC_ARG_WITH(qpe-includes,
    [  --with-qpe-includes     where the qpe includes are. ],
    [  
       ac_qpe_includes="$withval"
    ])
    
if test "$ac_qt_want_qte" = yes; then
  want_qte="yes"
  CXXFLAGS="$CXXFLAGS -fno-rtti -DQWS"
  LDFLAGS="$LDFLAGS -fno-rtti"
  LIB_QT="-lqte"
else
  want_qte="no"
  LIB_QT="-lqt"
fi

if test "$ac_qt_want_qpe" = yes; then
  want_qpe="yes"
fi

if test x$want_qpe = xyes; then
  if test "$ac_qpe_includes" = NO; then
    qpe_incdirs="${QPEDIR}"
    AC_FIND_FILE(qpe/qmovie.h, $qpe_incdirs, qpe_incdir)
    ac_qpe_includes=${qpe_incdir}
  fi
  LIB_QT="$LIB_QT -lqpe"
fi

if test "$ac_qt_includes" = NO || test "$ac_qt_libraries" = NO; then

AC_CACHE_VAL(ac_cv_have_qt,
AC_PATH_QT_DIRECT
[#try to guess qt locations

qt_incdirs="/usr/lib/qt/include /usr/local/qt/include /usr/include/qt /usr/include /usr/X11R6/include/X11/qt $QTINC"
test -n "$QTDIR" && qt_incdirs="$QTDIR/include $QTDIR $qt_incdirs"
AC_FIND_FILE(qmovie.h, $qt_incdirs, qt_incdir)
ac_qt_includes=$qt_incdir

qt_libdirs="/usr/lib/qt/lib /usr/local/qt/lib /usr/lib/qt /usr/lib $QTLIB"
test -n "$QTDIR" && qt_libdirs="$QTDIR/lib $QTDIR $qt_libdirs"
if test x$want_qte = xyes; then
  AC_FIND_FILE(libqte.so libqte.a, $qt_libdirs, qt_libdir)
else
  AC_FIND_FILE(libqt.so libqt.so.1 libqt.a libqt.sl, $qt_libdirs, qt_libdir)
fi
ac_qt_libraries=$qt_libdir

ac_cxxflags_safe=$CXXFLAGS
ac_ldflags_safe=$LDFLAGS
ac_libs_safe=$LIBS
CXXFLAGS="$CXXFLAGS -I$qt_incdir"
LDFLAGS="-L$qt_libdir"
LIBS=$LIB_QT

AC_LANG_SAVE
AC_LANG_CPLUSPLUS
cat > conftest.$ac_ext <<EOF
#include "confdefs.h"
#include <qmovie.h>
int main() {
  QMovie m;
  m.setSpeed(20);
  return 0;
};
EOF

if AC_TRY_EVAL(ac_link) && test -s conftest; then
  rm -f conftest*
else
  echo "configure: failed program was:" >&AC_FD_CC
  cat conftest.$ac_ext >&AC_FD_CC
  ac_qt_libraries="NO"
fi
rm -f conftest*
CXXFLAGS=$ac_cxxflags_safe
LDFLAGS=$ac_ldflags_safe
LIBS=$ac_libs_safe
AC_LANG_RESTORE

if test "$ac_qt_includes" = NO || test "$ac_qt_libraries" = NO || test "ac_qpe_includes" = NO; then
  ac_cv_have_qt="have_qt=no"
  ac_qt_notfound=""
  if test "$ac_qt_includes" = NO; then
    if test "$ac_qt_libraries" = NO; then
      ac_qt_notfound="(headers and libraries) ";
    else
      ac_qt_notfound="(headers) ";
    fi
  else
    ac_qt_notfound="(libraries) ";
  fi
else
  have_qt="yes"
fi
])
else
  have_qt="yes"
fi

eval "$ac_cv_have_qt"

if test "$have_qt" != yes; then
  AC_MSG_RESULT(missing);
#  AC_MSG_WARN([qt ${ac_qt_notfound}not found. Please check your installation! ]);
else
  ac_cv_have_qt="have_qt=yes \
    ac_qt_includes=$ac_qt_includes ac_qt_libraries=$ac_qt_libraries ac_qpe_includes=$ac_qpe_includes"
  if test x$want_qpe = xyes; then
    AC_MSG_RESULT([libraries $ac_qt_libraries, headers $ac_qt_includes $ac_qpe_includes])
  else
    AC_MSG_RESULT([libraries $ac_qt_libraries, headers $ac_qt_includes])
  fi
  
  qt_libraries=$ac_qt_libraries
  qt_includes=$ac_qt_includes
  qpe_includes=$ac_qpe_includes
fi
AC_SUBST(qt_libraries)
AC_SUBST(qt_includes)

QT_INCLUDES="-I$qt_includes"
QPE_INCLUDES="-I$qpe_includes"
QT_LDFLAGS="-L$qt_libraries"

AC_SUBST(QT_INCLUDES)
AC_SUBST(QPE_INCLUDES)
AC_SUBST(QT_LDFLAGS)
AC_SUBST(LIB_QT)

if test x$want_qpe = xyes; then
  AC_DEFINE(WANT_QPE)
fi

AC_PATH_QT_MOC
])
